
#ifndef LAYERSHELLQT_EXPORT_H
#define LAYERSHELLQT_EXPORT_H

#ifdef LAYERSHELLQTINTERFACE_STATIC_DEFINE
#  define LAYERSHELLQT_EXPORT
#  define LAYERSHELLQTINTERFACE_NO_EXPORT
#else
#  ifndef LAYERSHELLQT_EXPORT
#    ifdef LayerShellQtInterface_EXPORTS
        /* We are building this library */
#      define LAYERSHELLQT_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define LAYERSHELLQT_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef LAYERSHELLQTINTERFACE_NO_EXPORT
#    define LAYERSHELLQTINTERFACE_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef LAYERSHELLQTINTERFACE_DEPRECATED
#  define LAYERSHELLQTINTERFACE_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef LAYERSHELLQTINTERFACE_DEPRECATED_EXPORT
#  define LAYERSHELLQTINTERFACE_DEPRECATED_EXPORT LAYERSHELLQT_EXPORT LAYERSHELLQTINTERFACE_DEPRECATED
#endif

#ifndef LAYERSHELLQTINTERFACE_DEPRECATED_NO_EXPORT
#  define LAYERSHELLQTINTERFACE_DEPRECATED_NO_EXPORT LAYERSHELLQTINTERFACE_NO_EXPORT LAYERSHELLQTINTERFACE_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef LAYERSHELLQTINTERFACE_NO_DEPRECATED
#    define LAYERSHELLQTINTERFACE_NO_DEPRECATED
#  endif
#endif

#endif /* LAYERSHELLQT_EXPORT_H */
